@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/literals/)
 
 Usage::
 
@@ -36,8 +36,11 @@ __all__ = (
     "RelevanceLevelType",
     "SearchContentPaginatorName",
     "SearchSessionsPaginatorName",
+    "ConnectWisdomServiceServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
+    "RegionName",
 )
 
 
@@ -79,6 +82,7 @@ QueryAssistantPaginatorName = Literal["query_assistant"]
 RelevanceLevelType = Literal["HIGH", "LOW", "MEDIUM"]
 SearchContentPaginatorName = Literal["search_content"]
 SearchSessionsPaginatorName = Literal["search_sessions"]
+ConnectWisdomServiceServiceName = Literal["wisdom"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -112,6 +116,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
     "cloudcontrol",
@@ -366,6 +371,18 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_assistant_associations",
     "list_assistants",
@@ -375,3 +392,6 @@ PaginatorName = Literal[
     "search_content",
     "search_sessions",
 ]
+RegionName = Literal[
+    "ap-northeast-1", "ap-southeast-2", "eu-central-1", "eu-west-2", "us-east-1", "us-west-2"
+]
