@@ -1,7 +1,7 @@
 """
 Type annotations for wisdom service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_wisdom/type_defs/)
 
 Usage::
 
@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AssistantStatusType,
     ContentStatusType,
@@ -79,12 +81,16 @@ __all__ = (
     "KnowledgeBaseAssociationDataTypeDef",
     "KnowledgeBaseDataTypeDef",
     "KnowledgeBaseSummaryTypeDef",
+    "ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
     "ListAssistantAssociationsRequestRequestTypeDef",
     "ListAssistantAssociationsResponseTypeDef",
+    "ListAssistantsRequestListAssistantsPaginateTypeDef",
     "ListAssistantsRequestRequestTypeDef",
     "ListAssistantsResponseTypeDef",
+    "ListContentsRequestListContentsPaginateTypeDef",
     "ListContentsRequestRequestTypeDef",
     "ListContentsResponseTypeDef",
+    "ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef",
     "ListKnowledgeBasesRequestRequestTypeDef",
     "ListKnowledgeBasesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
@@ -93,6 +99,7 @@ __all__ = (
     "NotifyRecommendationsReceivedRequestRequestTypeDef",
     "NotifyRecommendationsReceivedResponseTypeDef",
     "PaginatorConfigTypeDef",
+    "QueryAssistantRequestQueryAssistantPaginateTypeDef",
     "QueryAssistantRequestRequestTypeDef",
     "QueryAssistantResponseTypeDef",
     "RecommendationDataTypeDef",
@@ -101,9 +108,11 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "ResultDataTypeDef",
     "SearchContentRequestRequestTypeDef",
+    "SearchContentRequestSearchContentPaginateTypeDef",
     "SearchContentResponseTypeDef",
     "SearchExpressionTypeDef",
     "SearchSessionsRequestRequestTypeDef",
+    "SearchSessionsRequestSearchSessionsPaginateTypeDef",
     "SearchSessionsResponseTypeDef",
     "ServerSideEncryptionConfigurationTypeDef",
     "SessionDataTypeDef",
@@ -755,6 +764,28 @@ class KnowledgeBaseSummaryTypeDef(
     pass
 
 
+_RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
+    "_RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
+    {
+        "assistantId": str,
+    },
+)
+_OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef = TypedDict(
+    "_OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef(
+    _RequiredListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef,
+    _OptionalListAssistantAssociationsRequestListAssistantAssociationsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListAssistantAssociationsRequestRequestTypeDef = TypedDict(
     "_RequiredListAssistantAssociationsRequestRequestTypeDef",
     {
@@ -787,6 +818,14 @@ ListAssistantAssociationsResponseTypeDef = TypedDict(
     },
 )
 
+ListAssistantsRequestListAssistantsPaginateTypeDef = TypedDict(
+    "ListAssistantsRequestListAssistantsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListAssistantsRequestRequestTypeDef = TypedDict(
     "ListAssistantsRequestRequestTypeDef",
     {
@@ -805,6 +844,28 @@ ListAssistantsResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredListContentsRequestListContentsPaginateTypeDef = TypedDict(
+    "_RequiredListContentsRequestListContentsPaginateTypeDef",
+    {
+        "knowledgeBaseId": str,
+    },
+)
+_OptionalListContentsRequestListContentsPaginateTypeDef = TypedDict(
+    "_OptionalListContentsRequestListContentsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListContentsRequestListContentsPaginateTypeDef(
+    _RequiredListContentsRequestListContentsPaginateTypeDef,
+    _OptionalListContentsRequestListContentsPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListContentsRequestRequestTypeDef = TypedDict(
     "_RequiredListContentsRequestRequestTypeDef",
     {
@@ -836,6 +897,14 @@ ListContentsResponseTypeDef = TypedDict(
     },
 )
 
+ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef = TypedDict(
+    "ListKnowledgeBasesRequestListKnowledgeBasesPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListKnowledgeBasesRequestRequestTypeDef = TypedDict(
     "ListKnowledgeBasesRequestRequestTypeDef",
     {
@@ -906,6 +975,29 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
+    "_RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef",
+    {
+        "assistantId": str,
+        "queryText": str,
+    },
+)
+_OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef = TypedDict(
+    "_OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class QueryAssistantRequestQueryAssistantPaginateTypeDef(
+    _RequiredQueryAssistantRequestQueryAssistantPaginateTypeDef,
+    _OptionalQueryAssistantRequestQueryAssistantPaginateTypeDef,
+):
+    pass
+
+
 _RequiredQueryAssistantRequestRequestTypeDef = TypedDict(
     "_RequiredQueryAssistantRequestRequestTypeDef",
     {
@@ -1030,6 +1122,29 @@ class SearchContentRequestRequestTypeDef(
     pass
 
 
+_RequiredSearchContentRequestSearchContentPaginateTypeDef = TypedDict(
+    "_RequiredSearchContentRequestSearchContentPaginateTypeDef",
+    {
+        "knowledgeBaseId": str,
+        "searchExpression": "SearchExpressionTypeDef",
+    },
+)
+_OptionalSearchContentRequestSearchContentPaginateTypeDef = TypedDict(
+    "_OptionalSearchContentRequestSearchContentPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class SearchContentRequestSearchContentPaginateTypeDef(
+    _RequiredSearchContentRequestSearchContentPaginateTypeDef,
+    _OptionalSearchContentRequestSearchContentPaginateTypeDef,
+):
+    pass
+
+
 SearchContentResponseTypeDef = TypedDict(
     "SearchContentResponseTypeDef",
     {
@@ -1069,6 +1184,29 @@ class SearchSessionsRequestRequestTypeDef(
     pass
 
 
+_RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
+    "_RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef",
+    {
+        "assistantId": str,
+        "searchExpression": "SearchExpressionTypeDef",
+    },
+)
+_OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef = TypedDict(
+    "_OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef",
+    {
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class SearchSessionsRequestSearchSessionsPaginateTypeDef(
+    _RequiredSearchSessionsRequestSearchSessionsPaginateTypeDef,
+    _OptionalSearchSessionsRequestSearchSessionsPaginateTypeDef,
+):
+    pass
+
+
 SearchSessionsResponseTypeDef = TypedDict(
     "SearchSessionsResponseTypeDef",
     {
